@@ -8,9 +8,9 @@ module Fog
       recognizes(
         :app_name,
         :app_version,
+        :google_application_default,
         :google_auth,
         :google_client,
-        :google_client_email,
         :google_client_options,
         :google_extra_global_projects,
         :google_key_location,
@@ -26,8 +26,10 @@ module Fog
                                           https://www.googleapis.com/auth/ndev.cloudman
                                           https://www.googleapis.com/auth/cloud-platform).freeze
       GOOGLE_COMPUTE_DEFAULT_NETWORK = "default".freeze
+      # TODO: Do we need those constants?
       RUNNING = "RUNNING".freeze
       PROVISIONING = "PROVISIONING".freeze
+      STAGING = "STAGING".freeze
 
       request_path "fog/compute/google/requests"
       request :add_backend_service_backends
@@ -194,6 +196,20 @@ module Fog
       request :invalidate_url_map_cache
       request :validate_url_map
 
+      request :get_instance_group_manager
+      request :insert_instance_group_manager
+      request :delete_instance_group_manager
+      request :list_instance_templates
+      request :list_instance_group_managers
+      request :get_instance_template
+      request :insert_instance_template
+      request :delete_instance_template
+
+      request :list_aggregated_instance_group_managers
+      request :set_instance_template
+      request :recreate_instances
+      request :abandon_instances
+
       request :deprecate_image
 
       model_path "fog/compute/google/models"
@@ -275,6 +291,12 @@ module Fog
       model :subnetwork
       collection :subnetworks
 
+      model :instance_template
+      collection :instance_templates
+
+      model :instance_group_manager
+      collection :instance_group_managers
+
       model :ssl_certificate
       collection :ssl_certificates
     end
