@@ -33,17 +33,24 @@ module Fog
 
           options = {
             :description => description || default_description,
-            :source_image => source_image,
-            :source_snapshot => source_snapshot,
-            :size_gb => size_gb,
             :type => type,
-            :zone => zone
+            :size_gb => size_gb,
+            :source_image => source_image,
+            :source_snapshot => source_snapshot
           }
 
-          data = service.insert_disk(name, zone, source_image, options)
+          if options[:source_image]
+            unless source_image.include?("projects/")
+              options[:source_image] = service.images.get(source_image).self_link
+            end
+          end
+
+          # Request needs backward compatibility so source image is specified in
+          # method arguments
+          data = service.insert_disk(name, zone, options[:source_image], options)
           operation = Fog::Compute::Google::Operations.new(:service => service)
                                                       .get(data.name, data.zone)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
           reload
         end
 
@@ -61,19 +68,51 @@ module Fog
           zone.nil? ? nil : zone.split("/")[-1]
         end
 
+        # Returns an attached disk configuration hash.
+        #
+        # Compute API needs attached disks to be specified in a custom format.
+        # This provides a handy shortcut for generating a preformatted config.
+        #
+        # Example output:
+        # {:auto_delete=>false,
+        #  :boot=>true,
+        #  :mode=>"READ_WRITE",
+        #  :source=>"https://www.googleapis.com/compute/v1/projects/myproj/zones/us-central1-f/disks/mydisk",
+        #  :type=>"PERSISTENT"}
+        #
+        # See Instances.insert API docs for more info:
+        # https://cloud.google.com/compute/docs/reference/rest/v1/instances/insert
+        #
+        # @param [Hash]  opts  options to attach the disk with.
+        #   @option opts [Boolean]  :writable  The mode in which to attach this
+        #     disk. (defaults to READ_WRITE)
+        #   @option opts [Boolean]  :boot  Indicates whether this is a boot disk.
+        #     (defaults to false)
+        #   @option opts [String]  :device_name  Specifies a unique device name
+        #     of your choice that is reflected into the /dev/disk/by-id/google-*
+        #     tree of a Linux operating system running within the instance.
+        #   @option opts [Object]  :encryption_key  Encrypts or decrypts a disk
+        #     using a customer-supplied encryption key.
+        #   @option opts [Object]  :auto_delete  Specifies whether the disk will
+        #     be auto-deleted when the instance is deleted. (defaults to false)
+        #
+        # @return [Hash] Attached disk configuration hash
         def attached_disk_obj(opts = {})
           requires :self_link
           collection.attached_disk_obj(self_link, opts)
         end
 
+        # A legacy shorthand for attached_disk_obj
+        #
+        # @param [Object]  writable  The mode in which to attach this disk.
+        #   (defaults to READ_WRITE)
+        # @param [Object]  auto_delete  Specifies whether the disk will be
+        #   auto-deleted when the instance is deleted. (defaults to false)
+        # @return [Hash]
         def get_as_boot_disk(writable = true, auto_delete = false)
-          {
-            :auto_delete => auto_delete,
-            :boot => true,
-            :source => self_link,
-            :mode =>  writable ? "READ_WRITE" : "READ_ONLY",
-            :type => "PERSISTENT"
-          }
+          attached_disk_obj(boot: true,
+                            writable: writable,
+                            auto_delete: auto_delete)
         end
 
         def ready?
@@ -101,7 +140,7 @@ module Fog
           data = service.create_disk_snapshot(snapshot_name, name, zone_name, snapshot)
           operation = Fog::Compute::Google::Operations.new(:service => service)
                                                       .get(data.name, data.zone)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
           service.snapshots.get(snapshot_name)
         end
 
