@@ -26,7 +26,7 @@ module Fog
           data = service.insert_subnetwork(identity, region, network, ip_cidr_range, attributes)
           operation = Fog::Compute::Google::Operations.new(:service => service)
                                                       .get(data.name, nil, data.region)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
           reload
         end
 
