@@ -5,15 +5,17 @@ module Fog
         model Fog::Compute::Google::UrlMap
 
         def all
-          data = service.list_url_maps.body["items"] || []
+          data = service.list_url_maps.to_h[:items] || []
           load(data)
         end
 
         def get(identity)
-          if url_map = service.get_url_map(identity).body
-            new(url_map)
+          if identity
+            url_map = service.get_url_map(identity).to_h
+            return new(url_map)
           end
-        rescue Fog::Errors::NotFound
+        rescue ::Google::Apis::ClientError => e
+          raise e unless e.status_code == 404
           nil
         end
       end
