@@ -9,13 +9,7 @@ module Fog
 
       class Real
         def delete_firewall(firewall_name)
-          api_method = @compute.firewalls.delete
-          parameters = {
-            "project" => @project,
-            "firewall" => firewall_name
-          }
-
-          request(api_method, parameters)
+          @compute.delete_firewall(@project, firewall_name)
         end
       end
     end
