@@ -9,14 +9,9 @@ module Fog
 
       class Real
         def list_instance_group_instances(group_name, zone)
-          api_method = @compute.instance_groups.list_instances
-          parameters = {
-            "instanceGroup" => group_name,
-            "project" => @project,
-            "zone" => zone
-          }
-
-          request(api_method, parameters)
+          @compute.list_instance_group_instances(@project,
+                                                 zone,
+                                                 group_name)
         end
       end
     end
