@@ -6,7 +6,7 @@ module Fog
       ##
       # A SSL certificate resource
       #
-      # @see https://developers.google.com/cloud-sql/docs/admin-api/v1beta3/sslCerts
+      # @see https://cloud.google.com/sql/docs/mysql/admin-api/v1beta4/sslCerts
       class SslCert < Fog::Model
         identity :sha1_fingerprint, :aliases => "sha1Fingerprint"
 
@@ -17,24 +17,24 @@ module Fog
         attribute :expiration_time, :aliases => "expirationTime"
         attribute :instance
         attribute :kind
+        attribute :self_link, :aliases => "selfLink"
 
         # These attributes are not available in the representation of a 'SSL Certificate' returned by the SQL API.
-        # These attributes are only available as a reponse to a create operation
+        # These attributes are only available as a response to a create operation
         attribute :server_ca_cert, :aliases => "serverCaCert"
         attribute :cert_private_key, :aliases => "certPrivateKey"
 
         ##
         # Deletes a SSL certificate. The change will not take effect until the instance is restarted.
         #
-        # @param [Hash] options Method options
-        # @option options [Boolean] :async If the operation must be performed asynchronously (true by default)
+        # @param async [Boolean] If the operation must be performed asynchronously (true by default)
         # @return [Fog::Google::SQL::Operation] A Operation resource
-        def destroy(options = {})
+        def destroy(async: true)
           requires :instance, :identity
 
           data = service.delete_ssl_cert(instance, identity)
-          operation = Fog::Google::SQL::Operations.new(:service => service).get(instance, data.body["operation"])
-          operation.wait_for { ready? } unless options.fetch(:async, true)
+          operation = Fog::Google::SQL::Operations.new(:service => service).get(data.name)
+          operation.wait_for { ready? } unless async
           operation
         end
 
@@ -59,10 +59,10 @@ module Fog
 
           raise Fog::Errors::Error.new("Resaving an existing object may create a duplicate") if persisted?
 
-          data = service.insert_ssl_cert(instance, common_name).body
-          merge_attributes(data["clientCert"]["certInfo"])
-          self.server_ca_cert = Fog::Google::SQL::SslCert.new(data["serverCaCert"])
-          self.cert_private_key = data["clientCert"]["certPrivateKey"]
+          data = service.insert_ssl_cert(instance, common_name)
+          merge_attributes(data.client_cert.cert_info.to_h)
+          self.server_ca_cert = Fog::Google::SQL::SslCert.new(data.server_ca_cert.to_h)
+          self.cert_private_key = data.client_cert.cert_private_key
           self
         end
       end
