@@ -15,9 +15,15 @@ module Fog
         attribute :kind
         attribute :project
 
-        def destroy(async: true)
+        def destroy(async = true)
           requires :instance, :name, :host
 
+          # TODO(2.0): Add a deprecation warning here, depending on the decision in #27
+          # This is a compatibility fix leftover from breaking named parameter change
+          if async.is_a?(Hash)
+            async = async[:async]
+          end
+
           resp = service.delete_user(instance, host, name)
           operation = Fog::Google::SQL::Operations.new(:service => service).get(resp.name)
           operation.wait_for { ready? } unless async
@@ -30,13 +36,13 @@ module Fog
           data = attributes
           data[:password] = password unless password.nil?
           if etag.nil?
-            resp = service.update_user(instance, data)
-          else
             resp = service.insert_user(instance, data)
+          else
+            resp = service.update_user(instance, data)
           end
 
           operation = Fog::Google::SQL::Operations.new(:service => service).get(resp.name)
-          operation.wait_for { !pending? }
+          operation.wait_for { ready? }
         end
       end
     end
