@@ -20,7 +20,13 @@ module Fog
         def host_path_query(params, expires)
           params[:headers]["Date"] = expires.to_i
           params[:path] = URI.encode(params[:path]).gsub("%2F", "/")
-          query = [params[:query]].compact
+          query = []
+
+          if params[:query]
+            filtered = params[:query].reject { |k, v| k.nil? || v.nil? }
+            query = filtered.map { |k, v| [k.to_s, Fog::Google.escape(v)].join("=") }
+          end
+
           query << "GoogleAccessId=#{@client.issuer}"
           query << "Signature=#{CGI.escape(signature(params))}"
           query << "Expires=#{params[:headers]['Date']}"
